@@ -62,6 +62,7 @@ fn expr(
         @strong ctx,
         @strong inspector,
         @strong source,
+        @strong on_change,
         @weak entry => move |b| {
         if !b.get_active() {
             if let Some((w, _)) = inspector.borrow_mut().take() {
@@ -70,15 +71,16 @@ fn expr(
         } else {
             let w = gtk::Window::new(gtk::WindowType::Toplevel);
             w.set_default_size(640, 480);
-            let on_change = {
-                let entry = entry.clone();
-                move |s: expr::Expr| {
+            let on_change = clone!(
+                @strong source, @strong entry, @strong on_change => move |s: expr::Expr| {
                     entry.set_text(&s.to_string());
-                    entry.emit_activate();
-                }
-            };
+                    entry.set_icon_from_icon_name(gtk::EntryIconPosition::Secondary, None);
+                    *source.borrow_mut() = s.clone();
+                    on_change(s);
+                });
             let si = ExprInspector::new(
                 ctx.clone(),
+                &w,
                 on_change,
                 source.borrow().clone()
             );
@@ -96,17 +98,15 @@ fn expr(
     (lbl, ibox, inspector)
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Table {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Table>>,
     dbg_path: DbgExpr,
     dbg_default_sort_column: DbgExpr,
-    dbg_default_sort_column_direction: DbgExpr,
-    dbg_column_mode: DbgExpr,
-    dbg_column_list: DbgExpr,
+    dbg_column_filter: DbgExpr,
     dbg_row_filter: DbgExpr,
-    dbg_editable: DbgExpr,
+    dbg_column_editable: DbgExpr,
     dbg_on_activate: DbgExpr,
     dbg_on_select: DbgExpr,
     dbg_on_edit: DbgExpr,
@@ -136,32 +136,12 @@ impl Table {
             }),
         );
         root.add((l, e));
-        let (l, e, dbg_default_sort_column_direction) = expr(
+        let (l, e, dbg_column_filter) = expr(
             ctx,
-            "Default Sort Column Direction:",
-            &spec.borrow().default_sort_column_direction,
+            "Column Filter:",
+            &spec.borrow().column_filter,
             clone!(@strong spec, @strong on_change => move |e| {
-                spec.borrow_mut().default_sort_column_direction = e;
-                on_change();
-            }),
-        );
-        root.add((l, e));
-        let (l, e, dbg_column_mode) = expr(
-            ctx,
-            "Column Filter Mode:",
-            &spec.borrow().column_mode,
-            clone!(@strong spec, @strong on_change => move |e| {
-                spec.borrow_mut().column_mode = e;
-                on_change()
-            }),
-        );
-        root.add((l, e));
-        let (l, e, dbg_column_list) = expr(
-            ctx,
-            "Column Filter List:",
-            &spec.borrow().column_list,
-            clone!(@strong spec, @strong on_change => move |e| {
-                spec.borrow_mut().column_list = e;
+                spec.borrow_mut().column_filter = e;
                 on_change()
             }),
         );
@@ -176,12 +156,12 @@ impl Table {
             }),
         );
         root.add((l, e));
-        let (l, e, dbg_editable) = expr(
+        let (l, e, dbg_column_editable) = expr(
             ctx,
-            "Editable:",
-            &spec.borrow().editable,
+            "Column Editable:",
+            &spec.borrow().column_editable,
             clone!(@strong spec, @strong on_change => move |e| {
-                spec.borrow_mut().editable = e;
+                spec.borrow_mut().column_editable = e;
                 on_change()
             }),
         );
@@ -221,11 +201,9 @@ impl Table {
             spec,
             dbg_path,
             dbg_default_sort_column,
-            dbg_default_sort_column_direction,
-            dbg_column_mode,
-            dbg_column_list,
+            dbg_column_filter,
             dbg_row_filter,
-            dbg_editable,
+            dbg_column_editable,
             dbg_on_activate,
             dbg_on_select,
             dbg_on_edit,
@@ -241,7 +219,7 @@ impl Table {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Action {
     root: TwoColGrid,
     spec: Rc<RefCell<expr::Expr>>,
@@ -298,7 +276,7 @@ impl Action {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Label {
     root: gtk::Box,
     spec: Rc<RefCell<expr::Expr>>,
@@ -334,7 +312,7 @@ impl Label {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Button {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Button>>,
@@ -389,7 +367,7 @@ impl Button {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct LinkButton {
     root: TwoColGrid,
     spec: Rc<RefCell<view::LinkButton>>,
@@ -462,7 +440,7 @@ impl LinkButton {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Toggle {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Toggle>>,
@@ -517,7 +495,7 @@ impl Toggle {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Selector {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Selector>>,
@@ -583,7 +561,7 @@ impl Selector {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Entry {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Entry>>,
@@ -668,14 +646,14 @@ impl Entry {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 struct Series {
     x: DbgExpr,
     y: DbgExpr,
     spec: Rc<RefCell<view::Series>>,
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct LinePlot {
     root: gtk::Box,
     spec: Rc<RefCell<view::LinePlot>>,
@@ -1026,7 +1004,7 @@ impl LinePlot {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct BoxChild {
     root: TwoColGrid,
     spec: Rc<RefCell<view::BoxChild>>,
@@ -1094,7 +1072,7 @@ fn dirselect(
     dircb
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Paned {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Paned>>,
@@ -1131,7 +1109,7 @@ impl Paned {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Frame {
     root: TwoColGrid,
     label_expr: DbgExpr,
@@ -1180,7 +1158,7 @@ impl Frame {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct BoxContainer {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Box>>,
@@ -1225,7 +1203,7 @@ impl BoxContainer {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct NotebookPage {
     root: TwoColGrid,
     spec: Rc<RefCell<view::NotebookPage>>,
@@ -1262,7 +1240,7 @@ impl NotebookPage {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Notebook {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Notebook>>,
@@ -1355,7 +1333,7 @@ impl Notebook {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct GridChild {
     root: TwoColGrid,
     spec: Rc<RefCell<view::GridChild>>,
@@ -1393,7 +1371,7 @@ impl GridChild {
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub(super) struct Grid {
     root: TwoColGrid,
     spec: Rc<RefCell<view::Grid>>,
